@@ -183,13 +183,22 @@ class IPKeyDimmer(GenericDimmer, HelperActionPress):
     def __init__(self, device_description, proxy, resolveparamsets=False):
         super().__init__(device_description, proxy, resolveparamsets)
 
+        channels = []
+        if "HMIP-DRDI3" in self.TYPE.upper():
+            channels = [1, 2, 3]
+        else:
+            channels = [1, 2]
+
         # init metadata
-        self.EVENTNODE.update({"PRESS_SHORT": [1, 2],
-                               "PRESS_LONG": [1, 2]})
+        self.EVENTNODE.update({"PRESS_SHORT": channels,
+                               "PRESS_LONG": channels})
 
     @property
     def ELEMENT(self):
-        return [4]
+        if "HMIP-DRDI3" in self.TYPE.upper():
+            return [5, 9, 13]
+        else:
+            return [4]
 
 
 class GenericSwitch(HMActor, HelperActorState):
@@ -377,12 +386,28 @@ class IPWDimmer(GenericDimmer, HelperDeviceTemperature, HelperWired):
             return [2, 6, 10]
         return [1]
 
-class IPWKeyBlindMulti(KeyBlind, HelperDeviceTemperature, HelperWired):
+class IPWKeyBlindMulti(KeyBlind, HelperActorBlindTilt,HelperDeviceTemperature, HelperWired):
     """
     Multi-blind actor HmIPW-DRBL4
     """
     def __init__(self, device_description, proxy, resolveparamsets=False):
         super().__init__(device_description, proxy, resolveparamsets)
+        self._shutter_channels = []
+        self._blind_channels = []
+
+        # Get Operation Mode for Input Channels
+        for chan in self.ELEMENT:
+            address_channel = "%s:%i" % (self._ADDRESS, chan -1)
+            try:
+                channel_paramset = self._proxy.getParamset(address_channel, "MASTER", 0)
+                channel_operation_mode = channel_paramset.get("CHANNEL_OPERATION_MODE") if "CHANNEL_OPERATION_MODE" in channel_paramset else 1
+                if channel_operation_mode == 0:
+                    self._blind_channels.append(chan)
+                    self.WRITENODE.pop("LEVEL_2", None)
+                else:
+                    self._shutter_channels.append(chan)
+            except Exception as err:
+                LOG.error("IPWKeyBlindMulti: Failure to determine channel mode of IPWKeyBlindMulti %s %s", address_channel, err)
 
         # init metadata
         self.ATTRIBUTENODE.update({"ACTIVITY_STATE": self.ELEMENT,
@@ -391,6 +416,18 @@ class IPWKeyBlindMulti(KeyBlind, HelperDeviceTemperature, HelperWired):
         self.ACTIONNODE.update({"STOP": self.ELEMENT})
         self.WRITENODE.update({"LEVEL": self.ELEMENT})
 
+        if len(self._shutter_channels) > 0:
+            self.WRITENODE.update({"LEVEL_2": self._shutter_channels})
+            self.SENSORNODE.update({"LEVEL_2": self._shutter_channels})
+
+    def close_slats(self, channel=None):
+        """Move the shutter up all the way."""
+        self.set_cover_tilt_position(0.0, channel)
+
+    def open_slats(self, channel=None):
+        """Move the shutter down all the way."""
+        self.set_cover_tilt_position(1.0, channel)
+
     @property
     def ELEMENT(self):
         return [2, 6, 10, 14]
@@ -417,8 +454,8 @@ class IPWInputDevice(HMEvent, HelperDeviceTemperature, HelperWired):
             except Exception as err:
                 LOG.error("IPWInputDevice: Failure to determine input channel operations mode of HmIPW input device %s: %s", address_channel, err)
 
-        self.ACTIONNODE.update({"PRESS_SHORT": self._hmipw_keypress_event_channels,
-                                "PRESS_LONG": self._hmipw_keypress_event_channels})
+        self.EVENTNODE.update({"PRESS_SHORT": self._hmipw_keypress_event_channels,
+                               "PRESS_LONG": self._hmipw_keypress_event_channels})
         self.BINARYNODE.update({"STATE": self._hmipw_binarysensor_channels})
 
     @property
@@ -535,7 +572,7 @@ class IPSwitch(GenericSwitch, HelperActionOnTime):
         super().__init__(device_description, proxy, resolveparamsets)
 
         channels = []
-        if "HMIP-PS" in self.TYPE.upper() or "HmIP-PCBS" in self.TYPE or "HmIP-DRSI1" in self.TYPE or "HmIP-FSI16" in self.TYPE:
+        if "HMIP-PS" in self.TYPE.upper() or "HmIP-PCBS" in self.TYPE or "HmIP-FSI16" in self.TYPE:
             channels = [1]
         elif "HmIP-MOD-OC8" in self.TYPE:
             channels = [1,2,3,4,5,6,7,8]
@@ -562,6 +599,26 @@ class IPSwitch(GenericSwitch, HelperActionOnTime):
             return [3]
 
 
+class IPSwitchRssiDevice(GenericSwitch, HelperActionOnTime, HelperRssiDevice):
+    """
+    Switch turning attached device on or off.
+    """
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        channels = []
+        if "HmIP-DRSI1" in self.TYPE:
+            channels = [1]
+
+        if channels:
+            self.EVENTNODE.update({"PRESS_SHORT": channels,
+                                   "PRESS_LONG": channels})
+
+    @property
+    def ELEMENT(self):
+        return [3]        
+
+        
 class IPSwitchBattery(GenericSwitch, HelperActionOnTime, HelperLowBatIP):
     """
     Battery powered switch turning attached device on or off.
@@ -730,7 +787,7 @@ class IPSwitchPowermeter(IPSwitch, HMSensor, HelperRssiDevice):
         sensorIndex = None
         if "HmIP-FSM" in self.TYPE or "HmIP-FSM16" in self.TYPE:
             sensorIndex = 5
-        elif "HMIP-PSM" in self.TYPE or "HmIP-PSM" in self.TYPE or "HmIP-PSM-CH" in self.TYPE:
+        elif "HMIP-PSM" in self.TYPE or "HmIP-PSM" in self.TYPE or "HmIP-USBSM" in self.TYPE or "HmIP-PSM-CH" in self.TYPE:
             sensorIndex = 6
         elif "HmIP-BSM" in self.TYPE:
             sensorIndex = 7
@@ -802,6 +859,24 @@ class IPGarage(GenericSwitch, GenericBlind, HMSensor):
         return [2]
 
 
+class IPGarageSwitch(GenericSwitch, HelperEventRemote, HMSensor):
+    """
+    HmIP-WGC Garage Actor
+    """
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        # init metadata
+        self.ATTRIBUTENODE.update({"LOW_BAT": [0],
+                                   "OPERATING_VOLTAGE": [0],
+                                   "RSSI_DEVICE": [0],
+                                   "RSSI_PEER": [0]})
+
+    @property
+    def ELEMENT(self):
+        return [3]
+
+
 class IPMultiIO(IPSwitch):
     """
     HmIP-MIOB Multi IO Box
@@ -945,6 +1020,51 @@ class ColdWarmDimmer(Dimmer):
 
         return self.setValue(key="LEVEL", channel=self._temp_channel, value=color_temp)
 
+
+class IPMultiIOPCB(GenericSwitch, HelperRssiDevice, HelperRssiPeer):
+    """HmIP-MIO16-PCB"""
+
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+
+        # Input channels (analog inputs 0-12V)
+        self._aic = [1, 4, 7, 10]
+        # Input channels (digital low active inputs)
+        self._dic = [13, 14, 15, 16]
+        # Output channels
+        # CH18, CH22, CH26, CH30: relay outputs (24 V/0,5 A)
+        # CH34, CH38, CH42, CH46: open collector outputs (30 V/0,2 A)
+        self._doc = [18, 22, 26, 30, 34, 38, 42, 46]
+
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        self._keypress_event_channels = []
+        self._binarysensor_channels = []
+        self._channel_operation_mode = 0
+
+        # Get Operation Mode for Input Channels
+        for chan in self._dic:
+            try:
+                self._channel_operation_mode = self._proxy.getParamset("%s:%i" % (self._ADDRESS, chan), "MASTER").get("CHANNEL_OPERATION_MODE", None)
+
+                if self._channel_operation_mode == 1:
+                    self._keypress_event_channels.append(chan)
+                elif self._channel_operation_mode != 0:
+                    self._binarysensor_channels.append(chan)
+            except Exception as err:
+                LOG.error("IPMultiIOPCB: Failure to determine input channel operations mode of IPMultiIOPCB %s:%i %s", self._ADDRESS, chan, err)
+
+        self.BINARYNODE.update({"STATE": self._binarysensor_channels})
+        self.SENSORNODE.update({"VOLTAGE": self._aic})
+        # button events not successfully implemented yet (SHORT_PRESS, LOMG_PRESS)
+
+    def get_voltage(self, channel=None):
+        """Return analog input in V"""
+        return float(self.getSensorData("VOLTAGE", channel))
+
+    @property
+    def ELEMENT(self):
+        return self._doc
+
 DEVICETYPES = {
     "HM-LC-Bl1-SM": Blind,
     "HM-LC-Bl1-SM-2": Blind,
@@ -1079,9 +1199,10 @@ DEVICETYPES = {
     "HmIP-PCBS-BAT": IPSwitchBattery,
     "HmIP-PMFS": IPSwitch,
     "HmIP-MOD-OC8": IPSwitch,
-    "HmIP-DRSI1": IPSwitch,
+    "HmIP-DRSI1": IPSwitchRssiDevice,
     "HmIP-DRSI4": IPSwitch,
     "HmIP-BSL": IPKeySwitchLevel,
+    "HmIP-USBSM": IPSwitchPowermeter,
     "HMIP-PSM": IPSwitchPowermeter,
     "HmIP-PSM": IPSwitchPowermeter,
     "HmIP-PSM-CH": IPSwitchPowermeter,
@@ -1094,6 +1215,7 @@ DEVICETYPES = {
     "HmIP-BSM": IPKeySwitchPowermeter,
     "HMIP-BDT": IPKeyDimmer,
     "HmIP-BDT": IPKeyDimmer,
+    "HmIP-DRDI3": IPKeyDimmer,
     "HmIP-FDT": IPDimmer,
     "HmIP-PDT": IPDimmer,
     "HmIP-PDT-UK": IPDimmer,
@@ -1106,9 +1228,11 @@ DEVICETYPES = {
     "HM-Sec-Sir-WM": RFSiren,
     "HmIP-MOD-HO": IPGarage,
     "HmIP-MOD-TM": IPGarage,
+    "HmIP-WGC": IPGarageSwitch,
     "HM-LC-RGBW-WM": ColorEffectLight,
     "HmIP-MIOB": IPMultiIO,
     "HM-DW-WM": Dimmer,
     "HM-LC-DW-WM": ColdWarmDimmer,
     "HB-UNI-RGB-LED-CTRL": ColorEffectLight,
+    "HmIP-MIO16-PCB": IPMultiIOPCB,
 }
