@@ -195,6 +195,20 @@ class CO2Sensor(SensorHm, HelperSensorState):
         return self.get_state(channel) == 2
 
 
+class CO2SensorIP(SensorHmIPNoBattery):
+    """CO2 Sensor
+        partial support for HmIP-SCTH230
+        missing relay state and actions
+    """
+
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+        self.SENSORNODE.update({"CONCENTRATION": [1],
+                                "CONCENTRATION_STATUS": [1],
+                                "HUMIDITY": [4],
+                                "ACTUAL_TEMPERATURE": [4]
+                                })
+
 class WaterSensor(SensorHm, HelperSensorState):
     """Watter detect sensor."""
 
@@ -220,7 +234,9 @@ class PowermeterGas(SensorHm):
         self.SENSORNODE.update({"GAS_ENERGY_COUNTER": [1],
                                 "GAS_POWER": [1],
                                 "ENERGY_COUNTER": [1],
-                                "POWER": [1]})
+                                "POWER": [1],
+                                "IEC_ENERGY_COUNTER": [1,2],
+                                "IEC_POWER": [1,2]})
 
     def get_gas_counter(self, channel=None):
         """Return gas counter."""
@@ -238,6 +254,14 @@ class PowermeterGas(SensorHm):
         """Return power counter."""
         return float(self.getSensorData("POWER", channel))
 
+    def get_iec_energy(self, channel=None):
+        """Return iec energy counter."""
+        return float(self.getSensorData("IEC_ENERGY_COUNTER", channel))
+
+    def get_iec_power(self, channel=None):
+        """Return iec power counter."""
+        return float(self.getSensorData("IEC_POWER", channel))
+
 
 class Smoke(SensorHm, HelperBinaryState):
     """Smoke alarm.
@@ -262,6 +286,21 @@ class SmokeV2(SensorHm, HelperBinaryState):
         """ Return True if smoke is detected """
         return self.get_state(channel)
 
+class SmokeV2Team(HMSensor, HelperBinaryState):
+    """This is a group of smoke sensors. In such a configuration only the
+       virtual team device will emit a smoke detected event."""
+
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        self.BINARYNODE.update({"STATE": [1]})
+
+        self.ATTRIBUTENODE.update({"SENDERADDRESS": [1],
+                                   "SENDERID": [1]})
+
+    def is_smoke(self, channel=None):
+        """ Return True if smoke is detected """
+        return self.get_state(channel)
 
 class IPSmoke(SensorHmIPNoVoltage):
     """HomeMatic IP Smoke sensor."""
@@ -426,6 +465,34 @@ class MotionIP(SensorHmIP):
         return [0, 1]
 
 
+class MotionIPContactSabotage(SensorHmIP, HelperSabotageIP):
+    """Motion detection indoor (rf ip)
+       This is a binary sensor."""
+
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        # init metadata
+        self.BINARYNODE.update({"MOTION_DETECTION_ACTIVE": [1], "MOTION": [1]})
+        self.SENSORNODE.update({"ILLUMINATION": [1]})
+        self.ATTRIBUTENODE.update({"ERROR_CODE": [0]})
+
+    def is_motion(self, channel=None):
+        """ Return True if motion is detected """
+        return bool(self.getBinaryData("MOTION", channel))
+
+    def is_motion_detection_active(self, channel=None):
+        return bool(self.getBinaryData("MOTION_DETECTION_ACTIVE", channel))
+
+    def get_brightness(self, channel=None):
+        """ Return brightness from 0 (dark) to 163830 (bright) """
+        return float(self.getSensorData("ILLUMINATION", channel))
+
+    @property
+    def ELEMENT(self):
+        return [0, 1]      
+      
+
 class MotionIPV2(SensorHmIP):
     """Motion detection indoor 55 (rf ip)
        This is a binary sensor."""
@@ -1048,7 +1115,23 @@ class ValveBox(SensorHmIP):
 
     @property
     def ELEMENT(self):
-        return [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
+        return [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
+
+class ValveBoxW(SensorHmIPW):
+    """Valve Box HmIPW-FALMOT-C12"""
+
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        self.SENSORNODE.update({"LEVEL": self.ELEMENT})
+
+    def get_level(self, channel=None):
+        """Return valve state from 0% to 99%"""
+        return float(self.getSensorData("LEVEL", channel))
+
+    @property
+    def ELEMENT(self):
+        return [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
 
 class IPLanRouter(HMSensor):
     """ HmIP Lan Router HmIP-HAP"""
@@ -1073,13 +1156,22 @@ class TempModuleSTE2(SensorHmIP):
         super().__init__(device_description, proxy, resolveparamsets)
 
         # init metadata
-        self.SENSORNODE.update({"ACTUAL_TEMPERATURE ": self.ELEMENT,
-                                "ACTUAL_TEMPERATURE_STATUS ": self.ELEMENT})
+        self.SENSORNODE.update({"ACTUAL_TEMPERATURE": self.ELEMENT,
+                                "ACTUAL_TEMPERATURE_STATUS": self.ELEMENT})
 
     @property
     def ELEMENT(self):
         return [1, 2, 3]
 
+class IPLockDLD(SensorHmIP):
+    """Lock state for HmIP-DLD."""
+
+    def __init__(self, device_description, proxy, resolveparamsets=False):
+        super().__init__(device_description, proxy, resolveparamsets)
+
+        # init metadata
+        self.SENSORNODE.update({"LOCK_STATE": [1]})
+
 DEVICETYPES = {
     "HM-Sec-SC": ShutterContact,
     "HM-Sec-SC-2": ShutterContact,
@@ -1108,6 +1200,7 @@ DEVICETYPES = {
     "HM-Sec-SD-Generic": Smoke,
     "HM-Sec-SD-2": SmokeV2,
     "HM-Sec-SD-2-Generic": SmokeV2,
+    "HM-Sec-SD-2-Team": SmokeV2Team,
     "HmIP-SWSD": IPSmoke,
     "HM-Sen-MDIR-WM55": RemoteMotion,
     "HM-Sen-MDIR-SM": Motion,
@@ -1120,7 +1213,7 @@ DEVICETYPES = {
     "HM-Sec-MDIR": MotionV2,
     "263 162": MotionV2,
     "HM-Sec-MD": MotionV2,
-    "HmIP-SMI": MotionIP,
+    "HmIP-SMI": MotionIPContactSabotage,
     "HmIP-SMI55": IPRemoteMotionV2,
     "HmIP-SMO": MotionIP,
     "HmIP-SMO-A": MotionIP,
@@ -1185,8 +1278,11 @@ DEVICETYPES = {
     "HmIP-ASIR": IPAlarmSensor,
     "HmIP-ASIR-2": IPAlarmSensor,
     "HmIP-FALMOT-C12": ValveBox,
+    "HmIPW-FALMOT-C12": ValveBoxW,
     "HmIP-SRD": IPRainSensor,
     "HmIP-HAP": IPLanRouter,
     "HB-WDS40-THP-O": WeatherStation,
-    "HmIP-STE2-PCB": TempModuleSTE2
+    "HmIP-STE2-PCB": TempModuleSTE2,
+    "HmIP-SCTH230": CO2SensorIP,
+    "HmIP-DLD": IPLockDLD,
 }
